# DeploymentTemplateStep

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**action_id** | **str** |  | [optional] 
**action_name** | **str** |  | [optional] 
**action_number** | **str** |  | [optional] 
**roles** | **list[str]** |  | [optional] 
**machine_names** | **list[str]** |  | [optional] 
**machines** | [**list[MachineDeploymentPreview]**](MachineDeploymentPreview.md) |  | [optional] 
**can_be_skipped** | **bool** |  | [optional] 
**is_disabled** | **bool** |  | [optional] 
**has_no_applicable_machines** | **bool** |  | [optional] 
**unavailable_machines** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 
**excluded_machines** | [**list[ReferenceDataItem]**](ReferenceDataItem.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


